Element

Enum Element 

#[non_exhaustive]
pub enum Element { Scalar { tag: Tag, value: Value, }, ContainerStart { tag: Tag, kind: ContainerKind, }, ContainerEnd, }
One step of the streaming reader.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Scalar

A complete scalar (or string/bytes) element.

Fields

tag: Tag

The tag that identifies this element within its enclosing context.

value: Value

The decoded scalar value.



ContainerStart

A container has just been opened. Subsequent next() calls return the container’s children until a matching ContainerEnd.

Fields

tag: Tag

The tag that identifies this container within its enclosing context.

kind: ContainerKind

Which container kind was opened.



ContainerEnd

The most recently-opened container has been closed.